@@ -1,4 +1,3 @@
-
 #' @title ggpairsModuleUI1: Variable selection module UI for ggpairs
 #' @description Variable selection module UI for ggpairs
 #' @param id id
@@ -55,7 +54,6 @@ ggpairsModuleUI1 <- function(id) {
   )
 }
 
-
 #' @title ggpairsModuleUI2: Option & download module UI for ggpairs
 #' @description Option & download module UI for ggpairs
 #' @param id id
@@ -115,9 +113,6 @@ ggpairsModuleUI2 <- function(id) {
   )
 }
 
-
-
-
 #' @title ggpairsModule: shiny module server for basic/scatter plot.
 #' @description Shiny module server for basic/scatter plot.
 #' @param input input
@@ -173,7 +168,6 @@ ggpairsModuleUI2 <- function(id) {
 
 
 ggpairsModule <- function(input, output, session, data, data_label, data_varStruct = NULL, nfactor.limit = 20) {
-
   ## To remove NOTE.
   val_label <- variable <- NULL
 
@@ -204,7 +198,6 @@ ggpairsModule <- function(input, output, session, data, data_label, data_varStru
   select_vars <- setdiff(names(data), except_vars)
   select_list <- mklist(data_varStruct, select_vars)
 
-
   output$vars_ggpairs <- renderUI({
     selectizeInput(session$ns("vars"), "Variables",
       choices = select_list, multiple = T,
@@ -221,10 +214,6 @@ ggpairsModule <- function(input, output, session, data, data_label, data_varStru
     )
   })
 
-
-
-
-
   output$gtype <- renderUI({
     tagList(
       h4("Upper"),
@@ -289,7 +278,6 @@ ggpairsModule <- function(input, output, session, data, data_label, data_varStru
     )
   })
 
-
   ggpairsInput <- reactive({
     data.val <- data
     for (i in factor_vars) {
@@ -321,26 +309,12 @@ ggpairsModule <- function(input, output, session, data, data_label, data_varStru
       )
     }
     class(p) <- c(class(p), "ggplot")
-    if (is.null(input$theme)) {
+    if (is.null(input$theme) | input$theme == "default") {
       return(p)
     }
-    if (input$theme == "default") {
-      return(p)
-    } else if (input$theme == "bw") {
-      return(p + theme_bw())
-    } else if (input$theme == "linedraw") {
-      return(p + theme_linedraw())
-    } else if (input$theme == "light") {
-      return(p + theme_light())
-    } else if (input$theme == "dark") {
-      return(p + theme_dark())
-    } else if (input$theme == "minimal") {
-      return(p + theme_minimal())
-    } else if (input$theme == "classic") {
-      return(p + theme_classic())
-    } else if (input$theme == "void") {
-      return(p + theme_void())
-    }
+
+    eval(parse(text = paste0('p <- p + theme_', input$theme, '()')))
+    return(p)
   })
 
   output$downloadControls <- renderUI({
@@ -395,12 +369,9 @@ ggpairsModule <- function(input, output, session, data, data_label, data_varStru
       )
     }
   )
-
   return(ggpairsInput)
 }
 
-
-
 #' @title ggpairsModule2: shiny module server for basic/scatter plot for reactive data.
 #' @description Shiny module server for basic/scatter plot for reactive data.
 #' @param input input
@@ -455,7 +426,6 @@ ggpairsModule <- function(input, output, session, data, data_label, data_varStru
 #' @importFrom officer read_pptx add_slide ph_with ph_location
 
 ggpairsModule2 <- function(input, output, session, data, data_label, data_varStruct = NULL, nfactor.limit = 20) {
-
   ## To remove NOTE.
   val_label <- variable <- NULL
 
@@ -463,7 +433,6 @@ ggpairsModule2 <- function(input, output, session, data, data_label, data_varStr
     data_varStruct <- reactive(list(variable = names(data())))
   }
 
-
   vlist <- reactive({
     mklist <- function(varlist, vars) {
       lapply(
@@ -504,9 +473,6 @@ ggpairsModule2 <- function(input, output, session, data, data_label, data_varStr
     ))
   })
 
-
-
-
   output$vars_ggpairs <- renderUI({
     selectizeInput(session$ns("vars"), "Variables",
       choices = vlist()$select_list, multiple = T,
@@ -535,10 +501,6 @@ ggpairsModule2 <- function(input, output, session, data, data_label, data_varStr
     )
   })
 
-
-
-
-
   output$gtype <- renderUI({
     tagList(
       h4("Upper"),
@@ -603,7 +565,6 @@ ggpairsModule2 <- function(input, output, session, data, data_label, data_varStr
     )
   })
 
-
   ggpairsInput <- reactive({
     data.val <- data()
     for (i in vlist()$factor_vars) {
@@ -635,26 +596,14 @@ ggpairsModule2 <- function(input, output, session, data, data_label, data_varStr
       )
     }
     class(p) <- c(class(p), "ggplot")
-    if (is.null(input$theme)) {
+
+    if (is.null(input$theme) | input$theme == "default") {
       return(p)
     }
-    if (input$theme == "default") {
-      return(p)
-    } else if (input$theme == "bw") {
-      return(p + theme_bw())
-    } else if (input$theme == "linedraw") {
-      return(p + theme_linedraw())
-    } else if (input$theme == "light") {
-      return(p + theme_light())
-    } else if (input$theme == "dark") {
-      return(p + theme_dark())
-    } else if (input$theme == "minimal") {
-      return(p + theme_minimal())
-    } else if (input$theme == "classic") {
-      return(p + theme_classic())
-    } else if (input$theme == "void") {
-      return(p + theme_void())
-    }
+
+    eval(parse(text = paste0('p <- p + theme_', input$theme, '()')))
+    return(p)
+
   })
 
   output$downloadControls <- renderUI({
